<?php

namespace Drupal\json_users_import\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\json_users_import\Controller\JsonUsersImportController;

/**
 * Provides a form to save the json users import configuration.
 */
class JsonUsersImportConfig extends ConfigFormBase {
	
	/**
	 * Implements \Drupal\Core\Form\FormInterface::getFormID().
	 */
	public function getFormId() {
		return 'json_users_import_configform';
	}

	/**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['json_users_import.import_configuration'];
  }

	/**
   * {@inheritdoc}
   */
	public function buildForm(array $form, FormStateInterface $form_state) {
		$config = $this->config('json_users_import.import_configuration');

		$jsonUsersImportController = new JsonUsersImportController();
		$fields = $jsonUsersImportController->getUserFields();

		$form['user_import_fieldmap'] = [
			'#type' => 'details',
			'#title' => t('User Import Field Configuration'),
			'#attributes' => ['id' => ['user_import_fieldmap']],
			'#open' => TRUE,
		];

		$form['user_import_fieldmap']['additional_fields'] = array(
	    '#type' => 'hidden',
	    '#value' => array_keys($fields), 
		);

		$form['user_import_fieldmap']['filed_email'] = [
      '#type' => 'textfield',
      '#title' => t('filed_email:'),
      '#default_value' => $config->get('filed_email'),
      '#required' => TRUE,
    ];

		$form['user_import_fieldmap']['filed_name'] = [
      '#type' => 'textfield',
      '#title' => t('filed_name:'),
      '#default_value' => $config->get('filed_name'),
      '#required' => TRUE,
    ];

		foreach ($fields as $fieldname => $fieldvalues) {
			$form['user_import_fieldmap'][$fieldname] = [
	      '#type' => 'textfield',
	      '#title' => t($fieldname.':'),
	      '#default_value' => $config->get($fieldname),
	    ];
		}

		$form['user_import_email_config'] = [
			'#type' => 'details',
			'#title' => t('E-Mail Configuration'),
			'#attributes' => ['id' => ['user_import_email_config']],
			'#open' => TRUE,
		];

		$form['user_import_email_config']['send_email'] = [
      '#type' => 'checkbox',
      '#title' => t('Send E-Mail to users'),
      '#default_value' => $config->get('send_email'),
      '#required' => FALSE,
      '#description' => '<p>' . t('Users will received email once user record is created successfully!.') . '</p>',
    ];

    $form['user_import_email_config']['email_subject'] = [
      '#type' => 'textfield',
      '#title' => t('Email Subject:'),
      '#default_value' => $config->get('email_subject'),
      '#states' => [
      	'visible' => [
      		[
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      	'and',
      	'required' => [
      		[
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      ],
		  '#token_types' => array('user'),
		  '#show_restricted' => TRUE,
    ];

    $options = [
		  'send_onetime_login' => t('Send One time login URL'),
		  'send_password' => t('Send Password'),
		];

    $form['user_import_email_config']['email_options'] = [
		  '#type' => 'radios',
		  '#title' => t('Select the E-Mail option'),
		  '#options' => $options,
		  '#default_value' => ($config->get('email_options')) ? $config->get('email_options') : 'send_onetime_login',
		  '#states' => [
      	'visible' => [
      		[
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      	'and',
      	'required' => [
      		[
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      ],
		];

    $form['user_import_email_config']['onetime_login_content'] = [
			'#type' => 'textarea',
			'#title' => t("Email Welcome Content:"),
			'#description' => '<p>' . t('Edit the welcome email messages sent to new member accounts created by an administrator. Available variables are:') . t('[site:name], [site:url], [user:display-name], [user:account-name], [user:mail], [site:login-url], [site:url-brief], [user:edit-url], [user:one-time-login-url].') .'</p>',
			'#default_value' => $config->get('onetime_login_content'),
			'#states' => [
      	'visible' => [
      		[
      			':input[name="email_options"]' => array('value' => 'send_onetime_login'),
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      	'and',
      	'required' => [
      		[
      			':input[name="email_options"]' => array('value' => 'send_onetime_login'),
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      ],
      '#token_types' => array('user'),
		];

		$form['user_import_email_config']['password_content'] = [
			'#type' => 'textarea',
			'#title' => t("Email Welcome Content:"),
			'#description' => '<p>' . t('Edit the welcome email messages sent to new member accounts created by an administrator. Available variables are:') . t('[site:name], [site:url], [user:display-name], [user:account-name], [user:mail], [site:login-url], [site:url-brief], [user-password].') .'</p>',
			'#default_value' => $config->get('password_content'),
			'#states' => [
      	'visible' => [
      		[
      			':input[name="email_options"]' => array('value' => 'send_password'),
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      	'and',
      	'required' => [
      		[
      			':input[name="email_options"]' => array('value' => 'send_password'),
      			':input[name="send_email"]' => array('checked' => TRUE),
      		],
      	],
      ],
      '#token_types' => array('user'),
		];

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];
		return $form;
	}

	/**
   * {@inheritdoc}
   */
	public function validateForm(array &$form, FormStateInterface $form_state) {

	}

	/**
   * {@inheritdoc}
   */
	public function submitForm(array &$form, FormStateInterface $form_state) {
		$values = $form_state->getValues();
    $config = $this->config('json_users_import.import_configuration');
    $config->set('filed_email', $values['filed_email'])->save();
    $config->set('filed_name', $values['filed_name'])->save();
    $config->set('send_email', $values['send_email'])->save();
    $config->set('email_subject', $values['email_subject'])->save();
    $config->set('email_options', $values['email_options'])->save();
    $config->set('onetime_login_content', $values['onetime_login_content'])->save();
    $config->set('password_content', $values['password_content'])->save();
    if($values['additional_fields']) {
			foreach ($values['additional_fields'] as $additionalFields) {
				$config->set($additionalFields, $values[$additionalFields])->save();
	    }
	  }
    \Drupal::messenger()->addMessage(t('Successfully saved!'));
	}
}